@@ -2,6 +2,7 @@ mod action;
 mod breakpoint;
 mod classes;
 mod orientation;
+mod position;
 mod size;
 mod space;
 
@@ -9,6 +10,7 @@ pub use action::*;
 pub use breakpoint::*;
 pub use classes::*;
 pub use orientation::*;
+pub use position::*;
 pub use size::*;
 pub use space::*;
 
